//go:build !debug
// +build !debug

package gore

func debugf(string, ...any) {}
